import logging
import os

from django.conf import settings
from django.views.generic.base import TemplateView

from . import settings as dj_jas_settings

import json as simplejson

logger = logging.getLogger("django_jasmine")


class DjangoJasmineView(TemplateView):
    template_name = "jasmine/index.html"

    def get_context_data(self, version=None):
        """Run the jasmine tests and render index.html"""
        root = settings.JASMINE_TEST_DIRECTORY
        # Get all files in spec dir and subdirs
        all_files = []
        for curpath, dirs, files in os.walk(os.path.join(root, "spec")):
            for name in files:
                if not name.startswith("."):
                    "We want to avoid .file.js.swp and co"
                    curpath = curpath.replace(os.path.join(root, "spec"), "")
                    all_files.append(os.path.join(curpath, name))

        suite = {}
        # defaults
        suite['js_files'] = []
        suite['static_files'] = []

        # load files.json if present
        if os.path.exists(os.path.join(root, "files.json")):
            file = open(os.path.join(root, 'files.json'), 'r')
            json = file.read()
            try:
                json = simplejson.loads(json)
            except ValueError:
                logger.info("You might have a syntax error in your files.json, "
                    "like a surplus comma")
                # Trick to call back the django handler500, couldn't find a way to
                # customize the Exception Type field in the debug Traceback
                json = simplejson.loads(json)
            suite.update(json)
            file.close()

        data = {
            'files': [fl for fl in all_files if fl.endswith('js')],
            'suite': suite,
            'version': version or dj_jas_settings.DEFAULT_JASMINE_VERSION,
        }
        return data



#!/usr/bin/env python
#from distutils.core import setup
from setuptools import setup, find_packages


META_DATA = dict(
    name='django-jasmine',
    version='0.5.1',
    description='Jasmine Javascript testing integration for Django.',
    long_description=open('README.rst').read(),
    author='Jonathan McCoy',
    author_email='modelsolutions@gmail.com',
    maintainer='Jake Harding',
    maintainer_email='jacobeharding@gmail.com',
    url='https://github.com/jakeharding/django-jasmine',
    keywords='django javascript test',
    classifiers=[
        "Development Status :: 4 - Beta",
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: JavaScript',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Testing',
    ],
    install_requires= ['Django>=1.8', ],
    packages=find_packages(exclude=["example_project", "tests"]),
    include_package_data=True,
    zip_safe=False,
    license='BSD'
)


if __name__ == "__main__":
    setup(**META_DATA)



import os

from django.conf.urls import url
from django.conf import settings
from django.views.static import serve

from .views import DjangoJasmineView

dj_jas_view = DjangoJasmineView.as_view()

urlpatterns = [
    url(r'^tests/(?P<path>.*)$', serve, {
        'document_root': os.path.join(settings.JASMINE_TEST_DIRECTORY, "spec"),
    }, name='jasmine_test'),
    url(r'^fixtures/(?P<path>.*)$', serve, {
        'document_root': os.path.join(
            settings.JASMINE_TEST_DIRECTORY, "fixtures",
        ),
    }, name='jasmine_fixtures'),
    url('^$', dj_jas_view, name='jasmine_default'),
    url('^(?P<version>.*)/$', dj_jas_view, name='jasmine_version'),
]
